]> sigrok.org Git - libsigrokdecode.git/blobdiff - log.c
Code cleanup
[libsigrokdecode.git] / log.c
diff --git a/log.c b/log.c
index d8e98ba2b692f99f6e272a45b4546f552076194c..46fa9e5fc5519da2e276d1294930ca2e96bb5c04 100644 (file)
--- a/log.c
+++ b/log.c
@@ -1,5 +1,5 @@
 /*
- * This file is part of the sigrok project.
+ * This file is part of the libsigrokdecode project.
  *
  * Copyright (C) 2011-2012 Uwe Hermann <uwe@hermann-uwe.de>
  *
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-#include "sigrokdecode.h" /* First, so we avoid a _POSIX_C_SOURCE warning. */
-#include "sigrokdecode-internal.h"
+#include "libsigrokdecode.h" /* First, so we avoid a _POSIX_C_SOURCE warning. */
+#include "libsigrokdecode-internal.h"
 #include <stdarg.h>
 #include <stdio.h>
 
+/**
+ * @file
+ *
+ * Controlling the libsigrokdecode message logging functionality.
+ */
+
+/**
+ * @defgroup grp_logging Logging
+ *
+ * Controlling the libsigrokdecode message logging functionality.
+ *
+ * @{
+ */
+
 /* Currently selected libsigrokdecode loglevel. Default: SRD_LOG_WARN. */
 static int srd_loglevel = SRD_LOG_WARN; /* Show errors+warnings per default. */
 
 /* Function prototype. */
-static int srd_logv(void *user_data, int loglevel, const char *format,
+static int srd_logv(void *cb_data, int loglevel, const char *format,
                    va_list args);
 
-/* Pointer to the currently selected log handler. Default: srd_logv(). */
-static srd_log_handler_t srd_log_handler = srd_logv;
+/* Pointer to the currently selected log callback. Default: srd_logv(). */
+static srd_log_callback_t srd_log_callback = srd_logv;
 
 /*
* Pointer to private data that can be passed to the log handler.
  * This can be used (for example) by C++ GUIs to pass a "this" pointer.
  */
-static void *srd_log_handler_data = NULL;
+static void *srd_log_callback_data = NULL;
 
 /* Log domain (a short string that is used as prefix for all messages). */
+/** @cond PRIVATE */
 #define LOGDOMAIN_MAXLEN 30
 #define LOGDOMAIN_DEFAULT "srd: "
+/** @endcond */
 static char srd_log_domain[LOGDOMAIN_MAXLEN + 1] = LOGDOMAIN_DEFAULT;
 
 /**
@@ -59,6 +75,8 @@ static char srd_log_domain[LOGDOMAIN_MAXLEN + 1] = LOGDOMAIN_DEFAULT;
  *                 SRD_LOG_WARN, SRD_LOG_INFO, SRD_LOG_DBG, or SRD_LOG_SPEW).
  *
  * @return SRD_OK upon success, SRD_ERR_ARG upon invalid loglevel.
+ *
+ * @since 0.1.0
  */
 SRD_API int srd_log_loglevel_set(int loglevel)
 {
@@ -78,6 +96,8 @@ SRD_API int srd_log_loglevel_set(int loglevel)
  * Get the libsigrokdecode loglevel.
  *
  * @return The currently configured libsigrokdecode loglevel.
+ *
+ * @since 0.1.0
  */
 SRD_API int srd_log_loglevel_get(void)
 {
@@ -97,6 +117,8 @@ SRD_API int srd_log_loglevel_get(void)
  *                  the caller does not need to keep it around.
  *
  * @return SRD_OK upon success, SRD_ERR_ARG upon invalid logdomain.
+ *
+ * @since 0.1.0
  */
 SRD_API int srd_log_logdomain_set(const char *logdomain)
 {
@@ -105,7 +127,6 @@ SRD_API int srd_log_logdomain_set(const char *logdomain)
                return SRD_ERR_ARG;
        }
 
-       /* TODO: Error handling. */
        snprintf((char *)&srd_log_domain, LOGDOMAIN_MAXLEN, "%s", logdomain);
 
        srd_dbg("Log domain set to '%s'.", (const char *)&srd_log_domain);
@@ -119,6 +140,8 @@ SRD_API int srd_log_logdomain_set(const char *logdomain)
  * @return A copy of the currently configured libsigrokdecode logdomain
  *         string. The caller is responsible for g_free()ing the string when
  *         it is no longer needed.
+ *
+ * @since 0.1.0
  */
 SRD_API char *srd_log_logdomain_get(void)
 {
@@ -126,64 +149,68 @@ SRD_API char *srd_log_logdomain_get(void)
 }
 
 /**
* Set the libsigrokdecode log handler to the specified function.
  *
* @param handler Function pointer to the log handler function to use.
*                Must not be NULL.
* @param user_data Pointer to private data to be passed on. This can be used
*                  by the caller to pass arbitrary data to the log functions.
*                  This pointer is only stored or passed on by libsigrokdecode,
*                  and is never used or interpreted in any way. The pointer
*                  is allowed to be NULL if the caller doesn't need/want to
*                  pass any data.
  *
  * @return SRD_OK upon success, SRD_ERR_ARG upon invalid arguments.
+ *
+ * @since 0.1.0
  */
-SRD_API int srd_log_handler_set(srd_log_handler_t handler, void *user_data)
+SRD_API int srd_log_callback_set(srd_log_callback_t cb, void *cb_data)
 {
-       if (!handler) {
-               srd_err("log: %s: handler was NULL", __func__);
+       if (!cb) {
+               srd_err("log: %s: cb was NULL", __func__);
                return SRD_ERR_ARG;
        }
 
/* Note: 'user_data' is allowed to be NULL. */
 
-       srd_log_handler = handler;
-       srd_log_handler_data = user_data;
+       srd_log_callback = cb;
+       srd_log_callback_data = cb_data;
 
        return SRD_OK;
 }
 
 /**
* Set the libsigrokdecode log handler to the default built-in one.
  *
* Additionally, the internal 'srd_log_handler_data' pointer is set to NULL.
  *
  * @return SRD_OK upon success, a (negative) error code otherwise.
+ *
+ * @since 0.1.0
  */
-SRD_API int srd_log_handler_set_default(void)
+SRD_API int srd_log_callback_set_default(void)
 {
        /*
         * Note: No log output in this function, as it should safely work
* even if the currently set log handler is buggy/broken.
         */
-       srd_log_handler = srd_logv;
-       srd_log_handler_data = NULL;
+       srd_log_callback = srd_logv;
+       srd_log_callback_data = NULL;
 
        return SRD_OK;
 }
 
-static int srd_logv(void *user_data, int loglevel, const char *format,
+static int srd_logv(void *cb_data, int loglevel, const char *format,
                    va_list args)
 {
        int ret;
 
-       /* This specific log handler doesn't need the void pointer data. */
-       (void)user_data;
+       /* This specific log callback doesn't need the void pointer data. */
+       (void)cb_data;
 
        /* Only output messages of at least the selected loglevel(s). */
        if (loglevel > srd_loglevel)
-               return SRD_OK; /* TODO? */
+               return SRD_OK;
 
        if (srd_log_domain[0] != '\0')
                fprintf(stderr, "%s", srd_log_domain);
@@ -193,74 +220,87 @@ static int srd_logv(void *user_data, int loglevel, const char *format,
        return ret;
 }
 
+/** @private */
 SRD_PRIV int srd_log(int loglevel, const char *format, ...)
 {
        int ret;
        va_list args;
 
        va_start(args, format);
-       ret = srd_log_handler(srd_log_handler_data, loglevel, format, args);
+       ret = srd_log_callback(srd_log_callback_data, loglevel, format, args);
        va_end(args);
 
        return ret;
 }
 
+/** @private */
 SRD_PRIV int srd_spew(const char *format, ...)
 {
        int ret;
        va_list args;
 
        va_start(args, format);
-       ret = srd_log_handler(srd_log_handler_data, SRD_LOG_SPEW, format, args);
+       ret = srd_log_callback(srd_log_callback_data, SRD_LOG_SPEW,
+                              format, args);
        va_end(args);
 
        return ret;
 }
 
+/** @private */
 SRD_PRIV int srd_dbg(const char *format, ...)
 {
        int ret;
        va_list args;
 
        va_start(args, format);
-       ret = srd_log_handler(srd_log_handler_data, SRD_LOG_DBG, format, args);
+       ret = srd_log_callback(srd_log_callback_data, SRD_LOG_DBG,
+                              format, args);
        va_end(args);
 
        return ret;
 }
 
+/** @private */
 SRD_PRIV int srd_info(const char *format, ...)
 {
        int ret;
        va_list args;
 
        va_start(args, format);
-       ret = srd_log_handler(srd_log_handler_data, SRD_LOG_INFO, format, args);
+       ret = srd_log_callback(srd_log_callback_data, SRD_LOG_INFO,
+                              format, args);
        va_end(args);
 
        return ret;
 }
 
+/** @private */
 SRD_PRIV int srd_warn(const char *format, ...)
 {
        int ret;
        va_list args;
 
        va_start(args, format);
-       ret = srd_log_handler(srd_log_handler_data, SRD_LOG_WARN, format, args);
+       ret = srd_log_callback(srd_log_callback_data, SRD_LOG_WARN,
+                              format, args);
        va_end(args);
 
        return ret;
 }
 
+/** @private */
 SRD_PRIV int srd_err(const char *format, ...)
 {
        int ret;
        va_list args;
 
        va_start(args, format);
-       ret = srd_log_handler(srd_log_handler_data, SRD_LOG_ERR, format, args);
+       ret = srd_log_callback(srd_log_callback_data, SRD_LOG_ERR,
+                              format, args);
        va_end(args);
 
        return ret;
 }
+
+/** @} */
@@ -1,5 +1,5 @@
 
 /*
- * Pointer to private data that can be passed to the log handler.
+ * Pointer to private data that can be passed to the log callback.
  * This can be used (for example) by C++ GUIs to pass a "this" pointer.
  */
@@ -126,64 +149,68 @@ SRD_API char *srd_log_logdomain_get(void)
 
 /**
- * Set the libsigrokdecode log handler to the specified function.
+ * Set the libsigrokdecode log callback to the specified function.
  *
@@ -126,64 +149,68 @@ SRD_API char *srd_log_logdomain_get(void)
  *
- * @param handler Function pointer to the log handler function to use.
- *                Must not be NULL.
- * @param user_data Pointer to private data to be passed on. This can be used
- *                  by the caller to pass arbitrary data to the log functions.
- *                  This pointer is only stored or passed on by libsigrokdecode,
- *                  and is never used or interpreted in any way. The pointer
- *                  is allowed to be NULL if the caller doesn't need/want to
- *                  pass any data.
+ * @param cb Function pointer to the log callback function to use.
+ *           Must not be NULL.
+ * @param cb_data Pointer to private data to be passed on. This can be used
+ *                by the caller to pass arbitrary data to the log functions.
+ *                This pointer is only stored or passed on by libsigrokdecode,
+ *                and is never used or interpreted in any way. The pointer
+ *                is allowed to be NULL if the caller doesn't need/want to
+ *                pass any data.
  *
  * @return SRD_OK upon success, SRD_ERR_ARG upon invalid arguments.
@@ -126,64 +149,68 @@ SRD_API char *srd_log_logdomain_get(void)
        }
 
-       /* Note: 'user_data' is allowed to be NULL. */
+       /* Note: 'cb_data' is allowed to be NULL. */
 
@@ -126,64 +149,68 @@ SRD_API char *srd_log_logdomain_get(void)
 
 /**
- * Set the libsigrokdecode log handler to the default built-in one.
+ * Set the libsigrokdecode log callback to the default built-in one.
  *
@@ -126,64 +149,68 @@ SRD_API char *srd_log_logdomain_get(void)
  *
- * Additionally, the internal 'srd_log_handler_data' pointer is set to NULL.
+ * Additionally, the internal 'srd_log_callback_data' pointer is set to NULL.
  *
  * @return SRD_OK upon success, a (negative) error code otherwise.
@@ -126,64 +149,68 @@ SRD_API char *srd_log_logdomain_get(void)
        /*
         * Note: No log output in this function, as it should safely work
-        * even if the currently set log handler is buggy/broken.
+        * even if the currently set log callback is buggy/broken.
         */